document.getElementById("Contents").innerHTML='\
    <ul><li><input type="checkbox" id="07"><label for="07">宏与脚本</label><ul>\
    <li><input type="checkbox" id="0701"><label for="0701">常规信息及用户界面用法</label><ul>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/main0601.html">LibreOffice Basic 帮助</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01000000.html">使用 LibreOffice Basic 编程</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/00000002.html">LibreOffice Basic 词汇表</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01010210.html">Basics</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01020000.html">语法</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01050000.html">LibreOffice Basic IDE</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01030100.html">IDE 概况</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01030200.html">Basic 编辑器</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01050100.html">监视窗口</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/main0211.html">宏工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/05060700.html">宏</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/vbasupport.html">对 VBA 宏的支持</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0702"><label for="0702">命令行参考</label><ul>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01020300.html">使用过程和函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01020500.html">程序库、模块和对话框</a></li>\
    <li><input type="checkbox" id="070202"><label for="070202">函数、语句及运算符</label><ul>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010000.html">屏幕 I/O 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020000.html">文件 I/O 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030000.html">日期与时间函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03050000.html">错误处理函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03060000.html">逻辑运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03070000.html">数学运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080000.html">数字函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090000.html">控制程序的执行</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100000.html">变量</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03040000.html">Basic 中的常量</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03110000.html">比较运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120000.html">字符串</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/special_vba_func.html">独家 VBA 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03130000.html">其他命令</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070201"><label for="070201">函数、语句及运算符列表 (字母顺序)</label><ul>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080601.html">Abs 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03060100.html">AND 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03104200.html">Array 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120101.html">Asc 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120111.html">AscW 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080101.html">Atn 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03130100.html">Beep 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010301.html">Blue 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100100.html">CBool 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120105.html">CByte 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100050.html">CCur 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030116.html">CDateFromUnoDateTime 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030115.html">CDateToUnoDateTime 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030114.html">CDateFromUnoTime 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030113.html">CDateToUnoTime 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030112.html">CDateFromUnoDate 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030111.html">CDateToUnoDate 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030108.html">CDateFromIso 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030107.html">CDateToIso 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100300.html">CDate 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100400.html">CDbl 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100060.html">CDec 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100500.html">CInt 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100600.html">CLng 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100900.html">CSng 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03101000.html">CStr 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090401.html">Call 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020401.html">ChDir 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020402.html">ChDrive 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090402.html">Choose 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120102.html">Chr 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120112.html">ChrW 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020101.html">Close 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03110100.html">比较运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100700.html">Const 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120313.html">ConvertFromURL 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120312.html">ConvertToURL 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080102.html">Cos 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03132400.html">CreateObject 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131800.html">CreateUnoDialog 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03132000.html">CreateUnoListener 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131600.html">CreateUnoService 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131500.html">CreateUnoStruct 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03132300.html">CreateUnoValue 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020403.html">CurDir 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100070.html">CVar 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03100080.html">CVErr 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030110.html">DateAdd 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030120.html">DateDiff 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030130.html">DatePart 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030101.html">DateSerial 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030102.html">DateValue 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030301.html">Date 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030103.html">Day 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140000.html">DDB 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090403.html">Declare 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03101100.html">DefBool 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03101300.html">DefDate 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03101400.html">DefDbl 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03101500.html">DefInt 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03101600.html">DefLng 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03101700.html">DefObj 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102000.html">DefVar 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03104300.html">DimArray 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102100.html">Dim 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020404.html">Dir 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090201.html">Do...Loop 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03110100.html">比较运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090404.html">End 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03130800.html">Environ 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020301.html">Eof 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03104600.html">EqualUnoObjects 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03060200.html">Eqv 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03050100.html">Erl 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03050200.html">Err 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03050300.html">Error 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03050000.html">错误处理函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090412.html">Exit 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080201.html">Exp 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020405.html">FileAttr 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020406.html">FileCopy 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020407.html">FileDateTime 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020415.html">FileExists 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020408.html">FileLen 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103800.html">FindObject 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103900.html">FindPropertyObject 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080501.html">Fix 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090202.html">For...Next 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120301.html">Format 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03150000.html">FormatDateTime 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03170010.html">FormatNumber 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020102.html">FreeFile 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090405.html">FreeLibrary 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090406.html">函数语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090400.html">其他语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140001.html">FV 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080300.html">生成随机数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020409.html">GetAttr 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03132500.html">GetDefaultContext 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03132100.html">GetGuiType 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131700.html">GetProcessServiceManager 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131000.html">GetSolarVersion 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03130700.html">GetSystemTicks 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020201.html">Get 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090301.html">GoSub...Return 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090302.html">GoTo 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010302.html">Green 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03104400.html">HasUnoInterfaces 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080801.html">Hex 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030201.html">Hour 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090103.html">IIf 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090101.html">If...Then...Else 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03060300.html">Imp 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120401.html">InStr 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120411.html">InStrRev 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03160000.html">Input 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010201.html">InputBox 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020202.html">Input# 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080502.html">Int 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140002.html">IPmt 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140003.html">IRR 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102200.html">IsArray 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102300.html">IsDate 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102400.html">IsEmpty 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03104000.html">IsMissing 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102600.html">IsNull 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102700.html">IsNumeric 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102800.html">IsObject 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03104500.html">IsUnoStruct 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120315.html">Join 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020410.html">Kill 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102900.html">LBound 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120302.html">LCase 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120304.html">LSet 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120305.html">LTrim 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120303.html">Left 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120402.html">Len 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103100.html">Let 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020203.html">Line Input # 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020302.html">Loc 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020303.html">Lof 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080202.html">Log 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120306.html">Mid 函数, Mid 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030202.html">Minute 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140004.html">MIRR 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020411.html">MkDir 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03070600.html">Mod 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030104.html">Month 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03150002.html">MonthName 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010102.html">MsgBox 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010101.html">MsgBox 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020412.html">Name 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03060400.html">Not 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030203.html">Now 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140005.html">NPer 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140006.html">NPV 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080000.html">数字函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080802.html">Oct 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03050500.html">On Error GoTo ... Resume 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090303.html">On...GoSub 语句; On...GoTo 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020103.html">Open 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103200.html">Option Base 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103300.html">Option Explicit 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103350.html">Option VBASupport 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03104100.html">Optional (函数语句)</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03060500.html">Or 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140007.html">Pmt 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140008.html">PPmt 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140009.html">PV 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010103.html">Print 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103400.html">Public 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020204.html">Put 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010304.html">QBColor 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140010.html">Rate 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010305.html">RGB 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120308.html">RSet 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120309.html">RTrim 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080301.html">Randomize 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03102101.html">ReDim 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03010303.html">Red 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090407.html">Rem 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020104.html">Reset 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120307.html">Right 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020413.html">RmDir 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080302.html">Rnd 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03170000.html">Round 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030204.html">Second 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020304.html">Seek 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020305.html">Seek 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090102.html">Select...Case 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020414.html">SetAttr 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103700.html">Set 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080701.html">Sgn 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03130500.html">Shell 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080103.html">Sin 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140011.html">SLN 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120201.html">Space 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120314.html">Split 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080401.html">Sqr 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080400.html">计算平方根</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103500.html">Static 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090408.html">Stop 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120403.html">StrComp 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120103.html">Str 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120412.html">StrReverse 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120202.html">String 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090409.html">Sub 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090410.html">Switch 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03140012.html">SYD 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080104.html">Tan 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030205.html">TimeSerial 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030206.html">TimeValue 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030302.html">Time 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030303.html">Timer 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03080100.html">三角函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120311.html">Trim 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131300.html">TwipsPerPixelX 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03131400.html">TwipsPerPixelY 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090413.html">Type 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103600.html">TypeName 函数; VarType 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03103000.html">UBound 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120310.html">UCase 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03120104.html">Val 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03130600.html">Wait 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030105.html">WeekDay 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03150001.html">WeekdayName 函数 [VBA]</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090203.html">While...Wend 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03090411.html">With 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03020205.html">Write 语句</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03060600.html">XOR 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03030106.html">Year 函数</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03070100.html">"-" 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03070200.html">"*" 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03070300.html">"+" 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03070400.html">"/" 运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03070500.html">"^" 运算符</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070205"><label for="070205">高级 Basic 库</label><ul>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_tools.html">工具库</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_depot.html">Depot 库</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_euro.html">Euro 库</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_formwizard.html">FormWizard 库</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_gimmicks.html">Gimmicks 库</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_schedule.html">Schedule 库</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_script.html">ScriptBindingLibrary 库</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_template.html">Template 库</a></li>\
			</ul></li>\
                    </ul></li>\
    <li><input type="checkbox" id="0703"><label for="0703">指南</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/macro_recording.html">记录宏</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/guide/control_properties.html">修改对话框编辑器中控件的属性</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/guide/insert_control.html">在对话框编辑器中创建控件</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/guide/sample_code.html">对话框编辑器中控件的编程示例</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/guide/show_dialog.html">通过程序代码打开对话框</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/guide/create_dialog.html">创建 Basic 对话框</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01030400.html">管理库和模块</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01020100.html">使用变量</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01020200.html">使用对象</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01030300.html">调试 Basic 程序</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/shared/01040000.html">事件驱动的宏</a></li>\
    <li><a target="_top" href="zh-CN/text/sbasic/guide/access2base.html">Access2Base</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="08"><label for="08">电子表格 (Calc)</label><ul>\
    <li><input type="checkbox" id="0801"><label for="0801">常规信息及用户界面用法</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/main0000.html">欢迎使用 LibreOffice Calc 帮助</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0503.html">LibreOffice Calc 电子表格的功能</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/keyboard.html">快捷键 (LibreOffice Calc 辅助功能)</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/04/01020000.html">电子表格的快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/05/02140000.html">LibreOffice Calc 中的错误代码</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060112.html">LibreOffice Calc 中用于编程的加载宏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/main.html">LibreOffice Calc 使用说明</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0802"><label for="0802">命令和菜单项指南</label><ul>\
    <li><input type="checkbox" id="080201"><label for="080201">菜单</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/main0100.html">菜单</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0101.html">文件</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0102.html">编辑</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0103.html">视图</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0104.html">插入</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0105.html">格式</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0116.html">工作表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0112.html">数据</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0106.html">工具</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0107.html">窗口</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0108.html">「帮助」菜单</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="080202"><label for="080202">工具栏</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/main0200.html">工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0202.html">「格式」工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0203.html">绘图对象属性栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0205.html">文字格式栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0206.html">公式栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0208.html">状态栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0210.html">「打印预览」工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0214.html">图像工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/main0218.html">工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0212.html">表格数据工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0214.html">查询设计栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0803"><label for="0803">函数 (公式) 类别及运算符</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060000.html">函数向导</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060100.html">函数清单 (根据类别)</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060107.html">矩阵函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060120.html">位操作函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060101.html">数据库函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060102.html">日期与时间函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060103.html">财务函数第一部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060119.html">财务函数第二部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060118.html">金融函数第三部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060104.html">信息函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060105.html">逻辑函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060106.html">数学函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060108.html">统计函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060181.html">统计函数第一部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060182.html">统计函数第二部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060183.html">统计函数第三部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060184.html">统计函数第四部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060185.html">统计函数第五部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060109.html">电子表格函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060110.html">文字函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060111.html">加载宏函数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060115.html">加载宏函数，分析函数列表第一部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060116.html">扩展函数，分析函数列表第二部分</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/01/04060199.html">LibreOffice Calc 中的运算符</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/userdefined_function.html">自定义函数</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0804"><label for="0804">载入、保存、导入及导出</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/webquery.html">在表格中插入外部数据 (WebQuery)</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/html_doc.html">将工作表以 HTML 格式保存和打开</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/csv_formula.html">导入与导出文本文件</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0805"><label for="0805">格式化</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/text_rotate.html">旋转文字</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/text_wrap.html">单元格内手动强制换行</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/text_numbers.html">将数字格式化为文本</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/super_subscript.html">文字上标/下标</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/row_height.html">改变行高或列宽</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cellstyle_conditional.html">应用条件格式</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cellstyle_minusvalue.html">高亮显示负数</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cellstyle_by_formula.html">根据公式指定的格式</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/integer_leading_zero.html">输入带前置零的数字</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/format_table.html">格式化电子表格</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/format_value.html">格式化带小数的数字</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/value_with_name.html">命名单元格</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/table_rotate.html">旋转表格 (转置)</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/rename_table.html">重命名工作表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/year2000.html">19xx/20xx 年</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/rounding_numbers.html">使用四舍五入的数字</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/currency_format.html">采用货币格式的单元格</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/autoformat.html">表格的自动格式</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/note_insert.html">插入和编辑批注</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/design.html">选择工作表主题</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/fraction_enter.html">输入分数</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0806"><label for="0806">筛选与排序</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/filters.html">应用筛选</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/specialfilter.html">筛选: 应用高级筛选</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/autofilter.html">添加自动筛选</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/sorted_list.html">应用排序列表</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0807"><label for="0807">打印</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/print_title_row.html">在每一页上打印行或列</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/print_landscape.html">横向打印工作表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/print_details.html">打印工作表详细资料</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/print_exact.html">定义打印的页数</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0808"><label for="0808">数据区域</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/database_define.html">定义数据库区域</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/database_filter.html">过滤单元格范围</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/database_sort.html">数据排序</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0809"><label for="0809">数据透视表</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot.html">数据透视表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot_createtable.html">创建数据透视表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot_deletetable.html">删除数据透视表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot_edittable.html">编辑透视表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot_filtertable.html">筛选数据透视表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot_tipps.html">选择数据透视表输出范围</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/datapilot_updatetable.html">更新数据透视表</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="08091"><label for="08091">数据透视图</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart.html">数据透视图</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_create.html">创建数据透视图</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_edit.html">编辑数据透视图</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_filter.html">筛选数据透视图</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_update.html">数据透视图更新</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/pivotchart_delete.html">删除数据透视图</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="0810"><label for="0810">方案</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/scenario.html">使用方案</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0811"><label for="0811">引用</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/relativ_absolut_ref.html">地址和引用，绝对和相对</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cellreferences.html">引用其他文档中的单元格</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cellreferences_url.html">引用其他工作表以及引用 URL</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cellreference_dragdrop.html">通过拖放来引用单元格</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/address_auto.html">将名称识别为地址</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0812"><label for="0812">查看、选择、复制</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/table_view.html">修改表格视图</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/formula_value.html">显示公式或数值</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/line_fix.html">行或列作为标题固定</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/multi_tables.html">浏览工作表标签</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/edit_multitables.html">复制到多个工作表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cellcopy.html">仅复制可见单元格</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/mark_cells.html">选择多个单元格</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0813"><label for="0813">公式与计算</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/formulas.html">通过公式计算</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/formula_copy.html">复制公式</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/formula_enter.html">输入公式</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/formula_value.html">显示公式或数值</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/calculate.html">电子表格中的计算</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/calc_date.html">使用日期与时间进行计算</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/calc_series.html">自动计算序列</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/calc_timevalues.html">计算时差</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/matrixformula.html">输入矩阵公式</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0814"><label for="0814">保护</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cell_protect.html">保护单元格不被修改</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/cell_unprotect.html">取消单元格保护</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0815"><label for="0815">其它选项</label><ul>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/auto_off.html">关闭自动更正功能</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/consolidate.html">合并计算数据</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/goalseek.html">应用单变量求解</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/multioperation.html">应用多重计算</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/multitables.html">应用多个工作表</a></li>\
    <li><a target="_top" href="zh-CN/text/scalc/guide/validity.html">单元格内容的有效性</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="05"><label for="05">图表与图示</label><ul>\
    <li><input type="checkbox" id="0501"><label for="0501">常规信息</label><ul>\
    <li><a target="_top" href="zh-CN/text/schart/main0000.html">LibreOffice 中的图表</a></li>\
    <li><a target="_top" href="zh-CN/text/schart/main0503.html">LibreOffice 图表功能</a></li>\
    <li><a target="_top" href="zh-CN/text/schart/04/01020000.html">图表的快捷键</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice 安装</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/ms_doctypes.html">修改 Microsoft Office 文档类型的关联</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/01/profile_safe_mode.html">安全模式</a></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="10"><label for="10">常见的帮助主题</label><ul>\
    <li><input type="checkbox" id="1001"><label for="1001">常规信息</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/main0400.html">快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/00/00000005.html">通用词汇表</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/00/00000002.html">Internet 术语词汇表</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/accessibility.html">LibreOffice 中的辅助功能</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/keyboard.html">快捷方式 (LibreOffice 辅助功能)</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/04/01010000.html">LibreOffice 中的常规快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/version_number.html">版本和编译号</a></li>\
</ul></li>\
    <li><input type="checkbox" id="1002"><label for="1002">LibreOffice 与 Microsoft Office</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/ms_user.html">使用 Microsoft Office 和 LibreOffice</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/microsoft_terms.html">比较 Microsoft Office 和 LibreOffice 的术语</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/ms_import_export_limitations.html">关于转换 Microsoft Office 文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/ms_doctypes.html">修改 Microsoft Office 文档类型的关联</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1004"><label for="1004">LibreOffice 选项</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01000000.html">选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010100.html">用户数据</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010200.html">常规</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010300.html">路径</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010400.html">写作辅助</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010600.html">常规</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010700.html">字体</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010800.html">视图</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01010900.html">打印选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01012000.html">应用程序颜色</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01013000.html">辅助功能</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/java.html">高级</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/expertconfig.html">专家配置</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/persona_firefox.html">个性化</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/BasicIDE.html">Basic IDE</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/opencl.html">Open CL</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01020000.html">加入/保存选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01030000.html">Internet 选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01040000.html">文本文档选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01050000.html">HTML 文档选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01060000.html">电子表格选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01070000.html">演示文稿选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01080000.html">绘图选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01090000.html">公式</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01110000.html">图表选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01130100.html">VBA 属性</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01130200.html">Microsoft Office</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01140000.html">语言</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01150000.html">语言设置选项</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/optionen/01160000.html">数据源选项</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1005"><label for="1005">向导</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/autopi/01000000.html">向导</a></li>\
    <li><input type="checkbox" id="100501"><label for="100501">信函向导</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/autopi/01010000.html">信函向导</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100502"><label for="100502">传真向导</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/autopi/01020000.html">传真向导</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100504"><label for="100504">会议议程向导</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/autopi/01040000.html">议程向导</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100506"><label for="100506">HTML 导出向导</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/autopi/01110000.html">HTML 导出</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100510"><label for="100510">文档转换器向导</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/autopi/01130000.html">文档转换器</a></li>\
			</ul></li>\
    <li><a target="_top" href="zh-CN/text/shared/autopi/01150000.html">欧元换算器向导</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1006"><label for="1006">配置 LibreOffice</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/configure_overview.html">配置 LibreOffice</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/01/packagemanager.html">扩展管理器</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/flat_icons.html">修改图标视图</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/edit_symbolbar.html">向工具栏添加按钮</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/workfolder.html">修改您的工作目录</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/standard_template.html">修改默认模板</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_addressbook.html">注册通讯簿</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/formfields.html">插入和编辑按钮</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1007"><label for="1007">用户界面使用</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/navigator_setcursor.html">快速浏览到对象</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/navigator.html">文档概览导航</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/autohide.html">显示、停靠和隐藏窗口</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/navpane_on.html">显示帮助的导航窗格</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/textmode_change.html">在插入模式和覆盖模式之间切换</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/floating_toolbar.html">使用工具栏</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="10071"><label for="10071">数字签名</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/digital_signatures.html">关于数字签名</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/digitalsign_send.html">应用数字签名</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/01/digitalsignaturespdf.html">导出 PDF 的数字签名</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/01/signexistingpdf.html">签署现有的 PDF</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/01/addsignatureline.html">在文本文档中添加签名行</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/01/signsignatureline.html">签署签名行</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="1008"><label for="1008">打印、传真、发送</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/labels_database.html">打印地址标签</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/print_blackwhite.html">黑白打印</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/email.html">将文档作为电子邮件发送</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/fax.html">发送传真和 LibreOffice 传真配置</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1009"><label for="1009">拖放</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop.html">在 LibreOffice 文档中拖放</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/dragdroptext.html">在文档中移动和复制文本</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_table.html">复制电子表格区域至文本文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_graphic.html">在文档之间复制图形</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图库复制图形</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_beamer.html">拖放数据源视图</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1010"><label for="1010">复制与粘贴</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/copy_drawfunctions.html">将图形对象复制到其他文档中</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_graphic.html">在文档之间复制图形</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图库复制图形</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_table.html">复制电子表格区域至文本文档</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1012"><label for="1012">图表与图示</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/chart_insert.html">插入图表</a></li>\
    <li><a target="_top" href="zh-CN/text/schart/main0000.html">LibreOffice 中的图表</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1013"><label for="1013">载入、保存、导入、导出</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/doc_open.html">打开文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/import_ms.html">打开以其他格式保存的文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/doc_save.html">保存文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/doc_autosave.html">自动保存文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/export_ms.html">以其他格式保存文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_dbase2office.html">以文本格式导入与导出数据</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1014"><label for="1014">链接与引用</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/hyperlink_insert.html">插入超链接</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/hyperlink_rel_abs.html">相对链接和绝对链接</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/hyperlink_edit.html">编辑超链接</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1015"><label for="1015">文档版本跟踪</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/redlining_doccompare.html">比较文档版本</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/redlining_docmerge.html">合并版本</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/redlining_enter.html">记录修改</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/redlining.html">记录和显示修改</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/redlining_accept.html">接受或拒绝修改</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/redlining_versions.html">版本管理</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1016"><label for="1016">标签与名片</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/labels.html">制作并打印标签和名片</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1018"><label for="1018">插入外部数据</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/copytable2application.html">从插入电子表格数据</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/copytext2application.html">插入文本文档数据</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/insert_bitmap.html">插入、编辑和保存位图</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_gallery.html">将图形添加到图库中</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1019"><label for="1019">自动函数</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/autocorr_url.html">关闭「自动 URL 识别」</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1020"><label for="1020">搜索与替换</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_search2.html">使用表单筛选器查找</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_search.html">查找表格和表单文档</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/01/02100001.html">正则表达式列表</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1021"><label for="1021">指南</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/guide/linestyles.html">应用线型</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/text_color.html">修改文字的颜色</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/change_title.html">修改文档的标题</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/round_corner.html">创建圆角</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/background.html">定义背景颜色或背景图形</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/lineend_define.html">定义线尾</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/linestyle_define.html">定义线型</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/insert_graphic_drawit.html">编辑图形对象</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/line_intext.html">在文本中绘制线条</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/aaa_start.html">第一个步骤</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/gallery_insert.html">从图库中插入对象</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/space_hyphen.html">插入不间断空格、不间断连字符和软连字符</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/insert_specialchar.html">插入特殊字符</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/tabs.html">插入和编辑制表位</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/protection.html">保护 LibreOffice 中的内容</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/redlining_protect.html">保护记录</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/pageformat_max.html">选择页面上的最大可打印区域</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/measurement_units.html">选择度量单位</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/language_select.html">选择文档语言</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_tabledefine.html">表格设计</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/numbering_stop.html">关闭单独段落的项目符号与编号</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="09"><label for="09">数据库功能 (Base)</label><ul>\
    <li><input type="checkbox" id="0901"><label for="0901">常规信息</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/explorer/database/main.html">LibreOffice 数据库</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/database_main.html">数据库摘要</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_new.html">创建新数据库</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_tables.html">使用表格</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_queries.html">使用查询</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_forms.html">使用表单</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_reports.html">创建报表</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_register.html">注册和删除数据库</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_im_export.html">导入与导出 Base 中的数据</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/guide/data_enter_sql.html">执行 SQL 命令</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="04"><label for="04">演示文稿与绘图 (Impress/Draw)</label><ul>\
    <li><input type="checkbox" id="0401"><label for="0401">常规信息及用户界面用法</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/main0000.html">欢迎使用 LibreOffice Impress 帮助</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0000.html">欢迎使用 LibreOffice Draw 帮助</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0503.html">LibreOffice Impress 功能</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0503.html">LibreOffice Draw 功能</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/keyboard.html">使用 LibreOffice Impress 中的快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/keyboard.html">绘图对象的快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/04/01020000.html">LibreOffice Impress 的快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/04/presenter.html">演讲者控制台快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/04/01020000.html">绘图快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/main.html">LibreOffice Impress 使用说明</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/main.html">LibreOffice Draw 使用说明</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0402"><label for="0402">命令和菜单项指南</label><ul>\
    <li><input type="checkbox" id="040201"><label for="040201">演示文稿 (LibreOffice Impress)</label><ul>\
    <li><input type="checkbox" id="04020101"><label for="04020101">菜单</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/main0100.html">菜单</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0101.html">文件</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0102.html">编辑</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0103.html">视图</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0104.html">插入</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0105.html">格式</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0117.html">幻灯片</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0114.html">幻灯片放映</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0106.html">工具</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0107.html">窗口</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0108.html">「帮助」菜单</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020102"><label for="04020102">工具栏</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/main0200.html">工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0202.html">线条和填充栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0203.html">文字格式栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0204.html">幻灯片视图中的对象栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0206.html">状态栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0209.html">标尺</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0210.html">绘图栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0211.html">大纲工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0212.html">「幻灯片浏览」栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0213.html">选项栏</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0214.html">图像栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0227.html">编辑接点栏</a></li>\
                 </ul></li>\
             </ul></li>\
    <li><input type="checkbox" id="040202"><label for="040202">绘图 (LibreOffice Draw)</label><ul>\
    <li><input type="checkbox" id="04020201"><label for="04020201">菜单</label><ul>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0100.html">菜单</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0101.html">文件</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0102.html">编辑</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0103.html">视图</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0104.html">插入</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0105.html">格式</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0106.html">工具</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0113.html">修改</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/main0107.html">窗口</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0108.html">「帮助」菜单</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020202"><label for="04020202">工具栏</label><ul>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0200.html">工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0210.html">绘图栏</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/main0213.html">选项工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0227.html">编辑接点栏</a></li>\
                 </ul></li>\
             </ul></li>\
         </ul></li>\
    <li><input type="checkbox" id="0403"><label for="0403">载入、保存、导入及导出</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/html_export.html">以 HTML 格式保存演示文稿</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/html_import.html">将 HTML 页面导入演示文稿</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/palette_files.html">加载颜色、渐变和阴影线列表。</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/animated_gif_save.html">以 GIF 格式导出动画</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/table_insert.html">在幻灯片中包括电子表格</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/graphic_insert.html">插入图形</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/page_copy.html">从其他演示文稿中复制幻灯片</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0404"><label for="0404">格式化</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/palette_files.html">加载颜色、渐变和阴影线列表。</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/line_arrow_styles.html">加载线条和箭头样式</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/color_define.html">定义自定义颜色</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/gradient.html">创建渐变填充</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/eyedropper.html">替换颜色</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/align_arrange.html">排列，对齐和分布对象</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/background.html">修改幻灯片背景填充</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/footer.html">向所有幻灯片添加页眉或页脚</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/masterpage.html">将幻灯片设计应用到幻灯片母版</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/move_object.html">移动对象</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0405"><label for="0405">打印</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/printing.html">打印演示文稿</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/print_tofit.html">根据纸张尺寸调整幻灯片打印</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0406"><label for="0406">特效</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/animated_gif_save.html">以 GIF 格式导出动画</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/animated_objects.html">为演示文稿幻灯片中的对象设置动画</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/animated_slidechange.html">以动画方式切换幻灯片</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/cross_fading.html">交叉淡入淡出两个对象</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/animated_gif_create.html">创建动画 GIF 图像</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0407"><label for="0407">对象、图形和位图</label><ul>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/combine_etc.html">结合对象与构造形状</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/draw_sector.html">绘制扇形和圆缺</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/duplicate_object.html">复制对象</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/rotate_object.html">旋转对象</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/join_objects3d.html">组合三维对象</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/join_objects.html">连接线条</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/text2curve.html">将文本字符转换为绘图对象</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/vectorize.html">将位图图像转换成矢量图形</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/3d_create.html">将二维对象转换成曲线、多边形和三维对象</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/line_arrow_styles.html">加载线条和箭头样式</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/line_draw.html">绘制曲线</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/line_edit.html">编辑曲线</a></li>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/graphic_insert.html">插入图形</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/table_insert.html">在幻灯片中包括电子表格</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/move_object.html">移动对象</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/select_object.html">选择底层对象</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/orgchart.html">创建流程图</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0408"><label for="0408">组合与分层</label><ul>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/groups.html">组合对象</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/layers.html">关于层</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/layer_new.html">插入层</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/layer_tipps.html">使用层</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/layer_move.html">将对象移至另一层</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0409"><label for="0409">演示文稿与绘图中的文字</label><ul>\
    <li><a target="_top" href="zh-CN/text/sdraw/guide/text_enter.html">添加文本</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/text2curve.html">将文本字符转换为绘图对象</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0410"><label for="0410">查看</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/arrange_slides.html">修改幻灯片顺序</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/change_scale.html">使用小键盘缩放</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0411"><label for="0411">幻灯片播放</label><ul>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/show.html">显示幻灯片放映</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/presenter_console.html">使用「演讲者控制台」</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/impress_remote.html">Impress Remote 指南</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/individual.html">创建自定义幻灯片放映</a></li>\
    <li><a target="_top" href="zh-CN/text/simpress/guide/rehearse_timings.html">幻灯片更换的排练计时</a></li>\
         </ul></li>\
     </ul></li></ul>\
    <ul><li><input type="checkbox" id="03"><label for="03">公式 (Math)</label><ul>\
    <li><input type="checkbox" id="0301"><label for="0301">常规信息及用户界面用法</label><ul>\
    <li><a target="_top" href="zh-CN/text/smath/main0000.html">欢迎使用 LibreOffice Math 帮助</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/main0503.html">LibreOffice Math 功能</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/guide/main.html">LibreOffice Math 使用说明</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/guide/keyboard.html">快捷方式 (LibreOffice Math 辅助功能)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0302"><label for="0302">命令和菜单项指南</label><ul>\
    <li><a target="_top" href="zh-CN/text/smath/main0100.html">菜单</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/main0200.html">工具栏</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0303"><label for="0303">使用公式</label><ul>\
    <li><a target="_top" href="zh-CN/text/smath/guide/align.html">手动对齐公式部分</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/guide/attributes.html">修改默认属性</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/guide/brackets.html">合并括号中的公式部分</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/guide/comment.html">输入注释</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/guide/newline.html">输入换行符</a></li>\
    <li><a target="_top" href="zh-CN/text/smath/guide/parentheses.html">插入括号</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="02"><label for="02">文本文档 (Writer)</label><ul>\
    <li><input type="checkbox" id="0201"><label for="0201">常规信息及用户界面用法</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/main0000.html">欢迎使用 LibreOffice Writer 文本文档帮助</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0503.html">LibreOffice Writer 的主要功能</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/main.html">LibreOffice Writer 使用说明</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/resize_navigator.html">固定窗口和调整窗口大小</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/04/01020000.html">用于 LibreOffice Writer 的快捷键</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/words_count.html">字数统计</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/keyboard.html">使用快捷键 (LibreOffice Writer 辅助功能)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0202"><label for="0202">命令和菜单项指南</label><ul>\
    <li><input type="checkbox" id="020201"><label for="020201">菜单</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/main0100.html">菜单</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0101.html">文件</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0102.html">编辑</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0103.html">视图</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0104.html">插入</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0105.html">格式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0115.html">样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0110.html">表格</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0120.html">表单菜单</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0106.html">工具</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0107.html">窗口</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0108.html">「帮助」菜单</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="020202"><label for="020202">工具栏</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/main0200.html">工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0202.html">「格式」工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0203.html">图像栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0204.html">表格栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0205.html">绘图对象属性栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0206.html">项目符号与编号栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0208.html">状态栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0210.html">打印预览</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0213.html">标尺</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0214.html">公式编辑栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0215.html">框架栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0216.html">OLE 对象栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/main0220.html">文字对象工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0212.html">表格数据工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0213.html">表单导航栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0214.html">查询设计栏</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/main0226.html">表单设计工具栏</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/librelogo/LibreLogo.html">LibreLogo 工具栏</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0203"><label for="0203">创建文本文档</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_nav_keyb.html">使用键盘浏览和选择</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_direct_cursor.html">使用直接定位光标</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0204"><label for="0204">文本文档中的图形</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic.html">插入图形</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_dialog.html">从文件中插入图形</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_gallery.html">使用拖放功能从图库插入图形</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_scan.html">插入扫描图像</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_fromchart.html">将 Calc 图表插入文本文档</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_graphic_fromdraw.html">从 LibreOffice Draw 或 Impress 插入图形</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0205"><label for="0205">文本文档中的表格</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/number_date_conv.html">打开或关闭表格中的数字识别</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/tablemode.html">通过键盘修改行和列</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/table_delete.html">删除表格或目录</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/table_insert.html">插入表格</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/table_repeat_multiple_headers.html">在新页面上重复表格标题</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/table_sizing.html">更改文本表格中行和列的大小</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/table_cells.html">使用键盘在表格中添加或删除行或列</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0206"><label for="0206">文本文档中的对象</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/anchor_object.html">定位对象</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/wrap.html">围绕对象的文字环绕</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0207"><label for="0207">文本文档中的章节及框架</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/sections.html">使用区域</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_frame.html">插入、编辑和链接文本框</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/section_edit.html">编辑区域</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/section_insert.html">插入区域</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0208"><label for="0208">目录与索引</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/chapter_numbering.html">章节编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_userdef.html">自定义索引</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_toc.html">创建目录</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_index.html">创建字母顺序索引</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_multidoc.html">覆盖多个文档的索引</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_literature.html">创建参考文献</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_delete.html">编辑或删除索引与目录条目</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_edit.html">更新、编辑和删除索引与目录</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_enter.html">定义索引或目录条目</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/indices_form.html">格式化索引或目录</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0209"><label for="0209">文本文档中的字段</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/fields.html">关于字段</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/fields_date.html">插入固定或可变的日期字段</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/field_convert.html">将字段转换成文本</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0210"><label for="0210">在文本文档中导航</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/dragdroptext.html">在文档中移动和复制文本</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/arrange_chapters.html">使用「导航」重新排列文档</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/hyperlinks.html">使用导航插入超链接</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/navigator.html">文本文档中的导航器</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0211"><label for="0211">文本文档中的计算</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/calculate_multitable.html">跨表格计算</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/calculate.html">在文本文档中计算</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/calculate_clipboard.html">在文本文档中计算并粘贴公式的结果</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/calculate_intable.html">计算表格中的单元格总计</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/calculate_intext.html">文本文档中的复杂公式计算</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/calculate_intext2.html">将表格计算结果显示到另一表格中</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0212"><label for="0212">格式化文本文档</label><ul>\
    <li><input type="checkbox" id="021201"><label for="021201">模板与样式</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/templates_styles.html">模板和样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/even_odd_sdw.html">对奇数页和偶数页应用不同的页面样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/change_header.html">根据当前页面创建页面样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/load_styles.html">使用其他文档或模板中的样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/stylist_fromselect.html">从选项中创建新样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/stylist_update.html">从选项中更新样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/template_create.html">创建文档模板</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/template_default.html">修改默认模板</a></li>\
			</ul></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/pageorientation.html">修改页面方向 (横向或纵向)</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_capital.html">修改文字的大小写</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/hidden_text.html">隐藏文本</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉与页脚</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_chapter.html">在页眉或页脚中插入章节名称和编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/shortcut_writing.html">输入时应用文本格式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/reset_format.html">重置字体属性</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/stylist_fillformat.html">在填充格式模式中应用样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/wrap.html">围绕对象的文字环绕</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_centervert.html">利用框架使文字在页面上居中</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_emphasize.html">强调文本</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_rotate.html">旋转文字</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/page_break.html">插入和删除分页符</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/pagestyles.html">创建和应用页面样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/subscript.html">将文字设为上标或下标</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0213"><label for="0213">特殊文本元素</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/captions.html">使用标题</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/conditional_text.html">有条件的文字</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/conditional_text2.html">用于页数的有条件的文字</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/fields_date.html">插入固定或可变的日期字段</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/fields_enter.html">添加输入字段</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/footer_nextpage.html">插入续页页码</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/footer_pagenumber.html">将页码插入页脚</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/hidden_text.html">隐藏文本</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉与页脚</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_chapter.html">在页眉或页脚中插入章节名称和编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/fields_userdata.html">按字段或条件查询用户数据</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/footnote_usage.html">插入和编辑脚注或尾注</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/footnote_with_line.html">脚注之间的间距</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/header_footer.html">关于页眉与页脚</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_line.html">格式化页眉或页脚</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/text_animation.html">使用文本动画</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/form_letters_main.html">创建格式信函</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0214"><label for="0214">自动函数</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/autocorr_except.html">将例外情况添加到自动更正列表中</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/autotext.html">使用自动图文集</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/auto_numbering.html">输入时创建编号/项目符号列表</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/auto_off.html">关闭自动更正</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/auto_spellcheck.html">自动检查拼写</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/number_date_conv.html">打开或关闭表格中的数字识别</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/using_hyphen.html">断词</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0215"><label for="0215">项目符号与编号</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/captions_numbers.html">向标题添加章节编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/auto_numbering.html">输入时创建编号/项目符号列表</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/chapter_numbering.html">章节编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_tab_innumbering.html">修改编号列表和项目符号列表的大纲级别</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/join_numbered_lists.html">合并编号列表</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/numbering_lines.html">添加行编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/numbering_paras.html">修改编号列表中的编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/number_sequence.html">定义编号范围</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/using_numbered_lists2.html">添加编号</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/using_numbering.html">编号和编号样式</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/using_numbered_lists.html">添加项目符号</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0216"><label for="0216">拼写检查、同义词库及语言选项</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/auto_spellcheck.html">自动检查拼写</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/delete_from_dict.html">从自定义词典中删除字</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/using_thesaurus.html">同义词库</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/spellcheck_dialog.html">检查拼写和语法</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0218"><label for="0218">疑难问题技巧</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/insert_beforetable.html">在页面顶部的表格之前插入文字</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/jump2statusbar.html">转到特定书签</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0219"><label for="0219">载入、保存、导入及导出</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/send2html.html">以 HTML 格式保存文本文档</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/textdoc_inframe.html">插入完整文本文档</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0220"><label for="0220">主控文档</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/globaldoc.html">主控文档和子文档</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0221"><label for="0221">链接与引用</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/references.html">插入交叉引用</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/hyperlinks.html">使用导航插入超链接</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0222"><label for="0222">打印</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/printer_tray.html">选择打印机纸张来源</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/print_preview.html">打印前预览页面</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/print_small.html">在一张纸上打印多个页面</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/pagestyles.html">创建和应用页面样式</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0223"><label for="0223">搜索与替换</label><ul>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/search_regexp.html">在文本查找中使用通配符</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/01/02100001.html">正则表达式列表</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="06"><label for="06">HTML 文档 (Writer Web)</label><ul>\
    <li><a target="_top" href="zh-CN/text/shared/07/09000000.html">网页</a></li>\
    <li><a target="_top" href="zh-CN/text/shared/02/01170700.html">HTML 筛选器和表单</a></li>\
    <li><a target="_top" href="zh-CN/text/swriter/guide/send2html.html">以 HTML 格式保存文本文档</a></li>\
	</ul></li></ul>\
';
